==> yos.core-2.2.1-sources.jar: utility/syslog.java <==
package utility;

import common.parameter.properties;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;

public class syslog {
    //    public String getSystemLog() throws Exception {
//        String filepath = Log4jProperties.getProperties().getProperty("log4j.appender.FILE.File");
//        StringBuffer stringBuffer = new StringBuffer();
//        File fileReader = new File(filepath);
//        InputStreamReader isr = new InputStreamReader(new FileInputStream(fileReader), "UTF-8");
//        BufferedReader bufferedReader = new BufferedReader(isr);
//        String s = null;
//        while ((s = bufferedReader.readLine()) != null) {
//            stringBuffer.append(System.lineSeparator() + s);
//        }
//        bufferedReader.close();
//        isr.close();
//        return stringBuffer.toString();
//    }
    public String getSystemLog() throws Exception {
        String filepath = properties.getLog4jProperties().getProperty("log4j.appender.FILE.File");
        StringBuffer stringBuffer = new StringBuffer();
        File fileReader = new File(filepath);
        FileInputStream fileInputStream = new FileInputStream(fileReader);
        InputStreamReader isr = new InputStreamReader(fileInputStream, "UTF-8");
        BufferedReader bufferedReader = new BufferedReader(isr);

        String str = null;
        while ((str = bufferedReader.readLine()) != null) {
            stringBuffer.append(System.lineSeparator() + str);
        }
        bufferedReader.close();
        isr.close();
        fileInputStream.close();
        return stringBuffer.toString();
    }
}

==> yos.core-2.5.17-sources.jar: utility/syslog.java <==
package utility;

import common.parameter.properties;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;

public class syslog {
    //    public String getSystemLog() throws Exception {
//        String filepath = Log4jProperties.getProperties().getProperty("log4j.appender.FILE.File");
//        StringBuffer stringBuffer = new StringBuffer();
//        File fileReader = new File(filepath);
//        InputStreamReader isr = new InputStreamReader(new FileInputStream(fileReader), "UTF-8");
//        BufferedReader bufferedReader = new BufferedReader(isr);
//        String s = null;
//        while ((s = bufferedReader.readLine()) != null) {
//            stringBuffer.append(System.lineSeparator() + s);
//        }
//        bufferedReader.close();
//        isr.close();
//        return stringBuffer.toString();
//    }
    public String getSystemLog() throws Exception {
        String filepath = properties.getLog4jProperties().getProperty("log4j.appender.FILE.File");
        StringBuilder stringBuilder = new StringBuilder();
        File fileReader = new File(filepath);
        FileInputStream fileInputStream = new FileInputStream(fileReader);
        InputStreamReader isr = new InputStreamReader(fileInputStream, "UTF-8");
        BufferedReader bufferedReader = new BufferedReader(isr);

        String str = null;
        while ((str = bufferedReader.readLine()) != null) {
            stringBuilder.append(System.lineSeparator()).append(str);
        }
        bufferedReader.close();
        isr.close();
        fileInputStream.close();
        return stringBuilder.toString();
    }
}
